@@ -22,7 +22,7 @@ extern "C" {
 #define HTML_ENTITY_REF_NODE	XML_ENTITY_REF_NODE
 #define HTML_COMMENT_NODE	XML_COMMENT_NODE
 
-void htmlDocDumpMemory(xmlDocPtr cur, CHAR**mem, int *size);
+void htmlDocDumpMemory(xmlDocPtr cur, xmlChar**mem, int *size);
 void htmlDocDump(FILE *f, xmlDocPtr cur);
 int htmlSaveFile(const char *filename, xmlDocPtr cur);
 
